"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

exports.__esModule = true;
exports.default = _default;

var _lodash = _interopRequireDefault(require("lodash"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _chalk = _interopRequireDefault(require("chalk"));

var _initConfig = _interopRequireDefault(require("../initConfig"));

var _checkDeps = _interopRequireDefault(require("../checkDeps"));

var _webpack = _interopRequireDefault(require("../webpack/webpack.config"));

var _createWebpackCompiler = _interopRequireDefault(require("../utils/createWebpackCompiler"));

var _printBuildError = _interopRequireDefault(require("../utils/printBuildError"));

var _logger = _interopRequireDefault(require("../utils/logger"));

function _default(entry, output, opts = {}) {
  if (opts.mode !== "production") {
    opts = _lodash.default.defaultsDeep({}, opts, {
      assets: {
        css: {
          name: "[name].css",
          chunkName: "[name].chunk.css"
        },
        js: {
          name: "[name].js",
          chunkName: "[name].chunk.js"
        },
        media: {
          name: "[name].[ext]"
        }
      },
      watch: true
    });
  }

  const config = (0, _initConfig.default)(entry, output, opts);

  _fsExtra.default.ensureDirSync(config.outputDir);

  if (config.clean) {
    _fsExtra.default.emptyDirSync(config.outputDir);
  }

  const watch = config.watch;
  const watchOptions = config.watchOptions;
  const compiler = (0, _createWebpackCompiler.default)(config);

  const printError = err => {
    (0, _logger.default)(_chalk.default.red("Failed to compile.\n"));
    (0, _printBuildError.default)(err);
  };

  const cb = err => {
    if (err) {
      if (!err.message) {
        printError(err);
      } else {
        printError(new Error(err.message));
      }
    }
  };

  if (watch) {
    compiler.watch(watchOptions, cb);
  } else {
    compiler.run(cb);
  }
}